Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit d2fd1f5
Tento commit je obsažen v:
Alex Voicu
2017-11-29 21:36:29 +00:00
rodič 93e595c267
revize 2557000b56
62 změnil soubory, kde provedl 152 přidání a 152 odebrání
+1 -1
Zobrazit soubor
@@ -35,7 +35,7 @@ THE SOFTWARE.
template<typename T>
__global__ void Inc(hipLaunchParm lp, T *Array){
int tx = threadIdx.x + blockIdx.x * blockDim.x;
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
Array[tx] = Array[tx] + T(1);
}